@@ -6,7 +6,8 @@
 # solver_conic_intf <- list(ECOS(), ECOS_BB(), CVXOPT(), GLPK(), XPRESS(), GLPK_MI(), CBC_CONIC(), SCS(), SuperSCS(), GUROBI_CONIC(), MOSEK(), CPLEX_CONIC())
 # solver_qp_intf <- list(OSQP(), GUROBI_QP(), CPLEX_QP())
 
-solver_conic_intf <- list(ECOS(), ECOS_BB(), CBC_CONIC(), CPLEX_CONIC(), GLPK_MI(), GLPK(), SCS(), GUROBI_CONIC(), MOSEK())
+solver_conic_intf <- list(ECOS(), ECOS_BB(), CBC_CONIC(), CPLEX_CONIC(), CVXOPT(),
+                          GLPK_MI(), GLPK(), SCS(), GUROBI_CONIC(), MOSEK())
 solver_qp_intf <- list(OSQP(), GUROBI_QP(), CPLEX_QP())
 
 SOLVER_MAP_CONIC <- solver_conic_intf
